@@ -6,7 +6,7 @@ from typing import NoReturn
 from typing import Sequence
 
 
-__version__ = "22.4.1"  # module-cli version
+__version__ = "22.4.2"  # module-cli version
 
 MODULE_S = """\
 from __future__ import annotations
@@ -73,7 +73,7 @@ if __name__ == "__main__":
 """
 
 
-def cli() -> NoReturn:
+def cli(args: Sequence[str] | None = None) -> NoReturn:
     raise SystemExit(main())
 
 
@@ -125,4 +125,4 @@ def handler(ns: argparse.Namespace) -> int:
 
 
 if __name__ == "__main__":
-    cli()
+    cli()  # pragma: no cover
